import pytvmaze
from datetime import datetime


def tvMazeCreator(items, mainChoice, tvName=None):
    if tvName is not None:
        return pytvmaze.show_search(str(tvName))
    else:
        return pytvmaze.show_search(items[int(mainChoice)].name)[int(mainChoice)]


def tvMazeDate(tvMaze):
    currentDate = datetime.strptime(datetime.now().strftime('%Y-%m-%d'), '%Y-%m-%d')
    try:
        nextReleaseDate = datetime.strptime(tvMaze.next_episode.airdate, '%Y-%m-%d').date()
        deltaDate = (nextReleaseDate - currentDate.date()).days
    except:
        nextReleaseDate = "---"
        deltaDate = "---"
    return deltaDate, nextReleaseDate


def extractTV(tvdbID, pItems):
    if tvdbID is not None:
        if len(pItems) > 0:
            for item in pItems:
                if item.externals['thetvdb'] == tvdbID:
                    return item
        else:
            return pItems


import os
from os.path import expanduser

# Global Section Variables
PATH = expanduser("~") + "/.config/tvdoon/"

def checkConfExist():
    # create conf directory
    if not os.path.exists(PATH):
        os.makedirs(PATH)

    # create favourite.conf file
    try:
        favFile = open(PATH + "favourites.conf", "r")
    except (OSError, IOError) as e:
        open(PATH + "favourites.conf", "a").close()

    return


import sys
import time
import threading

from utility import constants

class threadDotCount(threading.Thread):
    def __init__(self, threadID, name, daemon):
        threading.Thread.__init__(self)
        self.threadID = threadID
        self.name = name
        self.daemon = daemon
    def run(self):
        dotCountRun()

def dotCountRun():
    infoCounter = 0
    while constants.wholeCounter:
        if infoCounter == 0:
            sys.stdout.write("\r%s" % '')
            sys.stdout.flush()
            infoCounter = 1
            time.sleep(0.1)
        elif infoCounter == 1:
            sys.stdout.write("\r%s" % '.')
            sys.stdout.flush()
            infoCounter = 2
            time.sleep(0.1)
        elif infoCounter == 2:
            sys.stdout.write("\r%s" % '..')
            sys.stdout.flush()
            infoCounter = 3
            time.sleep(0.1)
        elif infoCounter== 3:
            sys.stdout.write("\r%s" % '...')
            sys.stdout.flush()
            infoCounter = 0
            time.sleep(0.1)


from setuptools import setup

setup(
    name="tvdoon",
    version="1.3.0",
    author="LinArcX",
    author_email="linarcx@gmail.com",
    description="Show Information About Tv Show's, Ratings And So Many Cool Features!",
    license=" GPLv3",
    keywords="tvShow, upcoming tvShow",
    url="https://github.com/LinArcX/tvdoon",
    download_url='https://github.com/LinArcX/tvdoon/archive/1.3.0.tar.gz',
    packages=['tvdoon','utility', 'threads'],
    install_requires= ['requests', 'pytvmaze','prettytable', 'pyfiglet', 'pip'],
    setup_requires = ['requests', 'pytvmaze', 'prettytable', 'pyfiglet', 'pip'],
    scripts=['tvdoon/tvdoon'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
        "Programming Language :: Python :: 3.6",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    ],
)



import threading
import pytvmaze
import sys

from datetime import datetime
from datetime import timedelta
from utility import constants

class threadSchedule(threading.Thread):
    def __init__(self, threadID, name, queue, currentDay, daemon, country='US', exceptdate=datetime.now().date()):
        threading.Thread.__init__(self)
        self.threadID = threadID
        self.name = name
        self.queue = queue
        self.currentDay = currentDay
        self.daemon = daemon
        self.country = country
        self.exceptdate = exceptdate

    def run(self):
        scheduleRun(self.queue, self.currentDay, self.country, self.exceptdate)

def scheduleRun(queue, currentDay, country, exceptDay):
    itemDict = []
    deltaDays = (exceptDay - currentDay).days
    print("==== From: " + str(currentDay) + ", To: " + str(exceptDay) + " ====")
    for day in range(0, deltaDays+1):
        nextDay = currentDay + timedelta(days=day)
        url = pytvmaze.endpoints.get_schedule.format(country, nextDay)
        try:
            constants.wholeCounter = 1
            q = pytvmaze.TVMaze._endpoint_standard_get(url)
            constants.wholeCounter = 0

            # flush current characters from current line in terminal
            sys.stdout.write("\r%s" % '')
            sys.stdout.flush()


            print(str(day) + ": In: " + "'" + str(nextDay) + "'" + ", We Found:" + "'" + str(len(q)) + "'" + " Episodes.")
            itemDict.append([pytvmaze.Episode(episode) for episode in q]) #  [nextDay] = [pytvmaze.Episode(episode) for episode in q]
        except:
            print("In: " + "'" + str(nextDay) + "'" + ", We Found:" + "'0'" + " Episodes.")
    queue.put(itemDict)
    return
